@@ -1,4 +1,4 @@
-getHaz <- function(Y, strats, score){
+getHaz <- function(Y, strats = NULL, score = NULL){
     if (NCOL(Y) == 2) {
         Y <- cbind(rep(0, NROW(Y)), Y)
         ##enter <- numeric(nn)
@@ -11,8 +11,8 @@ getHaz <- function(Y, strats, score){
         ##event <- (Y[, 3] != 0)
     }
 
-    if (missing(score)) score <- rep(1, NROW(Y))   # New 29 april 2015
-    if (missing(strats)) strats <- rep(1, NROW(Y)) # New 29 april 2015
+    if (is.null(score)) score <- rep(1, NROW(Y))   # New 29 april 2015
+    if (is.null(strats)) strats <- rep(1, NROW(Y)) # New 29 april 2015
     strats <- as.factor(strats)
     Strata <- levels(strats)
     ns <- length(Strata)
